==> wagtail_sb_imageserializer-0.1.0.tar.gz: wagtail_sb_imageserializer-0.1.0/README.md <==
![Community-Project](https://gitlab.com/softbutterfly/open-source/open-source-office/-/raw/master/banners/softbutterfly-open-source--banner--community-project.png)

![PyPI - Supported versions](https://img.shields.io/pypi/pyversions/wagtail-sb-imageserializer)
![PyPI - Package version](https://img.shields.io/pypi/v/wagtail-sb-imageserializer)
![PyPI - Downloads](https://img.shields.io/pypi/dm/wagtail-sb-imageserializer)
![PyPI - MIT License](https://img.shields.io/pypi/l/wagtail-sb-imageserializer)

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/329484ea99434c708f5c8dbd611f3d35)](https://app.codacy.com/gl/softbutterfly/wagtail-sb-imageserializer/dashboard?utm_source=gl&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)

# Wagtail Image Serializer

Wagtail package to render images with rendition in a single API Field.

## Requirements

- Python 3.8.1 or higher
- Django lower than 4.0
- Wagtail lower than 6.0

## Install

```bash
pip install wagtail-sb-imageserializer
```

## Usage

Add `wagtail_sb_imageserializer` to your `INSTALLED_APPS` settings

```
INSTALLED_APPS = [
  # ...
  "wagtail_sb_imageserializer",
  # ...
]
```

## Docs

- [Ejemplos](https://gitlab.com/softbutterfly/open-source/wagtail-sb-imageserializer/-/wikis)
- [Wiki](https://gitlab.com/softbutterfly/open-source/wagtail-sb-imageserializer/-/wikis)

## Changelog

All changes to versions of this library are listed in the [change history](CHANGELOG.md).

## Development

Check out our [contribution guide](CONTRIBUTING.md).

## Contributors

See the list of contributors [here](https://gitlab.com/softbutterfly/open-source/wagtail-sb-imageserializer/-/graphs/develop).

==> wagtail_sb_imageserializer-0.2.0.tar.gz: wagtail_sb_imageserializer-0.2.0/README.md <==
![Community-Project](https://gitlab.com/softbutterfly/open-source/open-source-office/-/raw/master/banners/softbutterfly-open-source--banner--community-project.png)

![PyPI - Supported versions](https://img.shields.io/pypi/pyversions/wagtail-sb-imageserializer)
![PyPI - Package version](https://img.shields.io/pypi/v/wagtail-sb-imageserializer)
![PyPI - Downloads](https://img.shields.io/pypi/dm/wagtail-sb-imageserializer)
![PyPI - MIT License](https://img.shields.io/pypi/l/wagtail-sb-imageserializer)

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/329484ea99434c708f5c8dbd611f3d35)](https://app.codacy.com/gl/softbutterfly/wagtail-sb-imageserializer/dashboard?utm_source=gl&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)

# Wagtail Image Serializer

Wagtail package to render images with rendition in a single API Field.

## Requirements

- Python 3.8.1 or higher
- Django lower than 4.0
- Wagtail lower than 6.0
- Django Rest Framework lower than 4.0

## Install

```bash
pip install wagtail-sb-imageserializer
```

## Usage

Add `wagtail.api.v2`, `rest_framework` and `wagtail_sb_imageserializer` to your `INSTALLED_APPS` settings

```
INSTALLED_APPS = [
  # ...
  "wagtail.api.v2",
  "rest_framework",
  "wagtail_sb_imageserializer",
  # ...
]
```

## Docs

- [Ejemplos](https://gitlab.com/softbutterfly/open-source/wagtail-sb-imageserializer/-/wikis)
- [Wiki](https://gitlab.com/softbutterfly/open-source/wagtail-sb-imageserializer/-/wikis)

## Changelog

All changes to versions of this library are listed in the [change history](CHANGELOG.md).

## Development

Check out our [contribution guide](CONTRIBUTING.md).

## Contributors

See the list of contributors [here](https://gitlab.com/softbutterfly/open-source/wagtail-sb-imageserializer/-/graphs/develop).
